#!/usr/bin/perl -w -I/usr/sausalito/perl -I.

# Copyright 2000, Cobalt Networks.  All rights reserved.
# $Id: 10_addSystem.pl,v 1.14 2000/10/23 22:16:47 pmartin Exp $
# author: jmayer@cobalt.com

use strict;
use CCE;

my $errors = 0;

my %locales = (  
	"en_US" => "&en&",
	"ja" => "&ja&"
);

my $cce = new CCE;
$cce->connectuds();

my ($fullbuild) = `cat /etc/build`;
chomp($fullbuild);

# figure out our product
my ($product, $build, $lang) = ($fullbuild =~ m/^build (\S+) for a (\S+) in (\S+)/);

# count the systems;
my @oids = $cce->find("System");
if ($#oids == 0) {
	# we have one and only one System object.  hooray.
} elsif ($#oids < 0) {
	# we must create a System object with no properties.
	$cce->create("System", {
		hostname=>"localhost",
		domainname=>"localdomain",
		productBuildString=>$fullbuild,
		productIdentity => $product,
		productBuild => $build,
		productLanguage => $lang,
		console=>"0",
		locales => $locales{$lang}
	})
} else { # we have more than one System object.
	print STDERR "ERROR: Multiple system objects detected!\n";
	print STDERR "       attempting to repair...\n";
	shift(@oids); # don't delete this one.
	foreach $_ (@oids) {
		my ($success) = $cce->destroy($_);
		if ($success) {
			print STDERR "       Deleted System object $_\n";
		} else {
			print STDERR "       FAILED to delete System object $_\n";
			$errors++;
		}
	}
}

# sync console (redundant on first create, safe on all others)
# we do it this way, because the console flag may change at powerup
my $conval = `/usr/sbin/cmos -c console`;
chomp($conval);
$cce->set($oids[0], "", {console => $conval eq "on" ? "1" : "0"}) if $oids[0];

$cce->bye();
exit($errors);
	

